#ifndef NT2_INCLUDE_FUNCTIONS_IF_ELSE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IF_ELSE_HPP_INCLUDED

#include <nt2/operator/include/functions/if_else.hpp>

#endif
